@@ -86,7 +86,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -211,6 +211,12 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_89(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55c00
+#  define KCOREADDONS_DEPRECATED_VERSION_5_92(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_92(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -277,7 +283,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -287,7 +293,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -402,6 +408,12 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_89(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55c00
+#  define KCOREADDONS_DEPRECATED_VERSION_5_92(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_92(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
